@@ -9,8 +9,9 @@ References,
 - https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
 - https://gist.github.com/XVilka/8346728
 - https://devblogs.microsoft.com/commandline/24-bit-color-in-the-windows-console/
-- http://jdebp.eu/Softwares/nosh/guide/TerminalCapabilities.html
+- http://jdebp.uk/Softwares/nosh/guide/TerminalCapabilities.html
 """
+
 # std imports
 import collections
 
@@ -21,8 +22,7 @@ __all__ = (
     'X11_COLORNAMES_TO_RGB',
 )
 
-CGA_COLORS = set(
-    ('black', 'red', 'green', 'yellow', 'blue', 'magenta', 'cyan', 'white'))
+CGA_COLORS = {'black', 'red', 'green', 'yellow', 'blue', 'magenta', 'cyan', 'white'}
 
 
 class RGBColor(collections.namedtuple("RGBColor", ["red", "green", "blue"])):
